#[repr(u8)]pub enum Datapause {
NORMAL = 0,
PAUSE = 1,
}Variants
NORMAL = 0
Normal operation, or resuming normal operation at the next frame if the I2S has already been paused.
PAUSE = 1
A pause in the data flow is being requested. It is in effect when DATAPAUSED in STAT = 1.
Implementations