#[repr(u8)]pub enum Pdmdata {
NORMAL = 0,
DMIC_SUBSYSTEM = 1,
}Variants
NORMAL = 0
Normal operation, data is transferred to or from the Flexcomm FIFO.
DMIC_SUBSYSTEM = 1
The data source is the D-Mic subsystem. When PDMDATA = 1, only the primary channel pair can be used in this Flexcomm. If ONECHANNEL = 1, only the PDM left data is used. the WS rate must match the Fs (sample rate) of the D-Mic decimator. A rate mismatch will at some point cause the I2S to overrun or underrun.
Implementations