#[repr(u8)]pub enum Txi2se0 {
LAST_VALUE = 0,
ZERO = 1,
}Variants
LAST_VALUE = 0
If the TX FIFO becomes empty, the last value is sent. This setting may be used when the data length is 24 bits or less, or when MONO = 1 for this channel pair.
ZERO = 1
If the TX FIFO becomes empty, 0 is sent. Use if the data length is greater than 24 bits or if zero fill is preferred.
Implementations